@@ -4,7 +4,7 @@ import sys
 from pathlib import Path
 
 __package__ = "meld"
-__version__ = "3.22.3"
+__version__ = "3.23.0"
 
 APPLICATION_NAME = 'Meld'
 APPLICATION_ID = 'org.gnome.Meld'
@@ -17,7 +17,8 @@ LOCALEDIR = Path(sys.prefix) / "share" / "locale"
 # END
 
 CONFIGURED = 'False'
-PROFILE = ''
+# Treat an unconfigured installation as development
+PROFILE = "Devel"
 
 if CONFIGURED == 'True':
     APPLICATION_ID = 'org.gnome.Meld'
@@ -43,11 +44,11 @@ def frozen():
     global DATADIR, LOCALEDIR, DATADIR_IS_UNINSTALLED
 
     melddir = os.path.dirname(sys.executable)
-    os.add_dll_directory(os.path.join(melddir, "lib"))
 
     DATADIR = os.path.join(melddir, "share", "meld")
     LOCALEDIR = os.path.join(melddir, "share", "mo")
     DATADIR_IS_UNINSTALLED = True
+    PROFILE = ""
 
 
 def uninstalled():
@@ -61,3 +62,15 @@ def uninstalled():
 
     resource_path = melddir / "meld" / "resources"
     os.environ['G_RESOURCE_OVERLAYS'] = f'{RESOURCE_BASE}={resource_path}'
+
+
+def setup_macos_application_bundle():
+    global DATADIR, LOCALEDIR, DATADIR_IS_UNINSTALLED
+
+    # When running from inside an application bundle, adjust paths relative
+    # to the location of the main binary.
+    base_dir = Path(sys.executable).resolve().parent.parent
+    share_dir = base_dir / "Resources" / "share"
+    DATADIR = share_dir / "meld"
+    LOCALEDIR = share_dir / "locale"
+    DATADIR_IS_UNINSTALLED = False
